/**
 * JORM: an implementation of a generic mapping system for persistent Java
 *       objects. Two mappings are supported: to RDBMS and to binary files.
 * Copyright (C) 2001-2004 France Telecom R&D - INRIA
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact: jorm-team@objectweb.org
 *
 */

package jorm;

import org.objectweb.jorm.naming.api.PBinder;
import org.objectweb.jorm.naming.api.PExceptionNaming;
import org.objectweb.jorm.api.PExceptionProtocol;
import org.objectweb.jorm.api.PException;
import org.objectweb.jorm.naming.api.PName;
import org.objectweb.jorm.naming.api.PNameCoder;
import org.objectweb.jorm.api.PSerializable;
import org.objectweb.jorm.api.PAccessor;
import org.objectweb.jorm.api.PAccessorGen;
import org.objectweb.jorm.api.PClassMapping;

public class JE2_CabinSerializable implements PSerializable, JE2_CabinAccessor {

	//the pname of the object
	protected String pName;
	
		protected int bedCount;
			protected int deckLevel;
			protected java.lang.Integer id;
			protected  String jonasCMRCabin_Reservation;
			protected java.lang.String name;
			protected  String ship;
	
	public String setPName(PName pName){
		if(pName.codingSupported((short) PNameCoder.CTSTRING)){
			try{
				this.pName  = pName.encodeString();
			}
			catch(Exception e){
			}
		}
		else{
			this.pName = "null";
		}
		return this.pName;
	}
	
	public PName getPName(PBinder pnc) throws PExceptionNaming{
		try{
			return pnc.decodeString(pName);
		}catch (Exception e) {
              throw new PExceptionNaming("Cannot decode to a PName: " + e.getMessage());
        }
	}
	
	public String getClassName(){
		return "jorm.JE2_Cabin";
	}
	

	public void paSetBedCount(int val){
		bedCount = val;
	}
	public int paGetBedCount() {
		return bedCount;
	}

	public void paSetDeckLevel(int val){
		deckLevel = val;
	}
	public int paGetDeckLevel() {
		return deckLevel;
	}

	public void paSetId(java.lang.Integer val){
		id = val;
	}
	public java.lang.Integer paGetId() {
		return id;
	}

	public void paSetJonasCMRCabin_Reservation(PName val, Object connection){
		if(val.codingSupported((short) PNameCoder.CTSTRING)){
			try{
				jonasCMRCabin_Reservation = val.encodeString();
			}
			catch(Exception e){
			}
		}
		else{
			jonasCMRCabin_Reservation = "null";
		}
	}
	
	public PName paGetJonasCMRCabin_Reservation(Object hints){
		PNameCoder pnc;
		if(hints instanceof PClassMapping){
			PClassMapping pcm = (PClassMapping) hints;
			pnc = pcm.getPNameCoder("jonasCMRCabin_Reservation");
		}
		else{
			if(hints instanceof PNameCoder){
				pnc = (PNameCoder) hints;
			}
			else
				return null;
		}
		try{
			return pnc.decodeString(jonasCMRCabin_Reservation);
		}
		catch(PException e){
			return null;
		}
	}

	public void paSetName(java.lang.String val){
		name = val;
	}
	public java.lang.String paGetName() {
		return name;
	}

	public void paSetShip(PName val, Object connection){
		if(val.codingSupported((short) PNameCoder.CTSTRING)){
			try{
				ship = val.encodeString();
			}
			catch(Exception e){
			}
		}
		else{
			ship = "null";
		}
	}
	
	public PName paGetShip(Object hints){
		PNameCoder pnc;
		if(hints instanceof PClassMapping){
			PClassMapping pcm = (PClassMapping) hints;
			pnc = pcm.getPNameCoder("ship");
		}
		else{
			if(hints instanceof PNameCoder){
				pnc = (PNameCoder) hints;
			}
			else
				return null;
		}
		try{
			return pnc.decodeString(ship);
		}
		catch(PException e){
			return null;
		}
	}

	public Object getMemoryInstance(){
		return this;
	}
	
	
	public String toString(){
		StringBuffer s = new StringBuffer();
		s.append("data(");
					s.append(bedCount + ",  ");
					s.append(deckLevel + ",  ");
					s.append(id + ",  ");
					s.append(jonasCMRCabin_Reservation + ",  ");
					s.append(name + ",  ");
					s.append(ship + ",  ");
				s.append(pName + ")");
		return s.toString();
	}
	
	
	public void read(PClassMapping pcm, PAccessor pa) throws PException{
		JE2_CabinAccessor paccessor = null;
		PAccessorGen paccessorGen = null;
		if (pa == null)
			throw new PException("Accessor must not be null");
		else if (pa instanceof JE2_CabinAccessor)
			paccessor = (JE2_CabinAccessor) pa;
		else if (pa instanceof PAccessorGen)
			paccessorGen = (PAccessorGen) pa;
		else
			throw new PException("Wrong type of accessor: " + pa);
	 	try {	
			if(paccessor != null){
											paccessor.paSetBedCount(paGetBedCount());
															paccessor.paSetDeckLevel(paGetDeckLevel());
															paccessor.paSetId(paGetId());
															paccessor.paSetJonasCMRCabin_Reservation(paGetJonasCMRCabin_Reservation(pcm), null);
															paccessor.paSetName(paGetName());
															paccessor.paSetShip(paGetShip(pcm), null);
							 			}
 			else{
	  		 			        		//paccessorGen.paSetIntField("bedCount", paGetBedCount(pcm), null);
	        			 			        		//paccessorGen.paSetIntField("deckLevel", paGetDeckLevel(pcm), null);
	        			 			        		//paccessorGen.paSetOintField("id", paGetId(pcm), null);
	        			 						 			        		//paccessorGen.paSetStringField("name", paGetName(pcm), null);
	        			 						        	 }  
		}
 		catch (PException pe) {
			throw pe;
		} catch (Exception e) {
			throw new PException(e.toString());
		} 
	}
	
	public void write(PClassMapping pcm, PAccessor pa) throws PException{
		JE2_CabinAccessor paccessor = null;
		PAccessorGen paccessorGen = null;
		if (pa == null)
			throw new PExceptionProtocol("Accessor must not be null");
		else if (pa instanceof JE2_CabinAccessor)
			paccessor = (JE2_CabinAccessor) pa;
		else if (pa instanceof PAccessorGen)
			paccessorGen = (PAccessorGen) pa;
		else
			throw new PExceptionProtocol("Wrong type of accessor: " + pa);
		try {	
			if(paccessor != null){
											paSetBedCount(paccessor.paGetBedCount());
															paSetDeckLevel(paccessor.paGetDeckLevel());
															paSetId(paccessor.paGetId());
															paSetJonasCMRCabin_Reservation(paccessor.paGetJonasCMRCabin_Reservation(pcm), null);
															paSetName(paccessor.paGetName());
															paSetShip(paccessor.paGetShip(pcm), null);
							 			}
 			else{
	  		 				        	//	paSetIntField(bedCount, paccessorGen.paGetBedCount());
        		//paSetIntField("bedCount", paccessorGen.paGetIntField("bedCount"));
        		//paSetBedCount(paccessorGen.paGetIntField("bedCount"), null);
	        			 				        	//	paSetIntField(deckLevel, paccessorGen.paGetDeckLevel());
        		//paSetIntField("deckLevel", paccessorGen.paGetIntField("deckLevel"));
        		//paSetDeckLevel(paccessorGen.paGetIntField("deckLevel"), null);
	        			 				        	//	paSetOintField(id, paccessorGen.paGetId());
        		//paSetOintField("id", paccessorGen.paGetOintField("id"));
        		//paSetId(paccessorGen.paGetOintField("id"), null);
	        			 						 				        	//	paSetStringField(name, paccessorGen.paGetName());
        		//paSetStringField("name", paccessorGen.paGetStringField("name"));
        		//paSetName(paccessorGen.paGetStringField("name"), null);
	        			 						        	 }  
		}
 		catch (PException pe) {
			throw pe;
		} catch (Exception e) {
			throw new PException(e.toString());
		} 
	}
}